| Title: | Graphical Interface for Loading Datasets |
|---|---|
| Description: | Graphical interface for loading datasets in RStudio from all installed (including unloaded) packages, also includes command line interfaces. |
| Authors: | Bastiaan quast [aut, cre] (ORCID: <https://orcid.org/0000-0002-2951-3577>) |
| Maintainer: | Bastiaan quast <[email protected]> |
| License: | GPL-3 |
| Version: | 2.3.0 |
| Built: | 2026-06-07 08:36:48 UTC |
| Source: | https://github.com/bquast/datasets.load |
List all datasets
alldata(package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE)alldata(package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE)
package |
a character vector with the names of packages to search through, or NULL in which "all" packages (as defined by argument all) are searched. |
lib.loc |
a character vector of directory names of R libraries, or NULL. The default value of NULL corresponds to all libraries currently known. |
all |
logical; if TRUE search all available packages in the library trees specified by lib.loc, and if FALSE, search only attached packages. |
drop.defaults |
logical; if TRUE, do not include the datasets from the datasets package. |
List datasets in an HTML Browser
browseDatasets( package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE )browseDatasets( package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE )
package |
a character vector with the names of packages to search through, or NULL in which "all" packages (as defined by argument all) are searched. |
lib.loc |
a character vector of directory names of R libraries, or NULL. The default value of NULL corresponds to all libraries currently known. |
all |
logical; if TRUE search all available packages in the library trees specified by lib.loc, and if FALSE, search only attached packages. |
drop.defaults |
logical; if TRUE, do not include the datasets from the datasets package. |
View datasets from all installed packages
datasets(package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE)datasets(package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE)
package |
a character vector with the names of packages to search through, or NULL in which "all" packages (as defined by argument all) are searched. |
lib.loc |
a character vector of directory names of R libraries, or NULL. The default value of NULL corresponds to all libraries currently known. |
all |
logical; if TRUE search all available packages in the library trees specified by lib.loc, and if FALSE, search only attached packages. |
drop.defaults |
logical; if TRUE, do not include the datasets from the datasets package. |
Load Datasets from a Menu
datasets.load()datasets.load()
Get information on installed datasets.
getDatasetInfo( package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE )getDatasetInfo( package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE )
package |
a character vector with the names of packages to search through, or NULL in which "all" packages (as defined by argument all) are searched. |
lib.loc |
a character vector of directory names of R libraries, or NULL. The default value of NULL corresponds to all libraries currently known. |
all |
logical; if TRUE search all available packages in the library trees specified by lib.loc, and if FALSE, search only attached packages. |
drop.defaults |
logical; if TRUE, do not include the datasets from the datasets package. |
Print function for browseDatasets objects
## S3 method for class 'browseDatasets' print(x, ...)## S3 method for class 'browseDatasets' print(x, ...)
x |
Object of class datasets |
... |
Further arguments, ignored by the print method. |
Print function for datasets class objects
## S3 method for class 'datasets' print(x, ...)## S3 method for class 'datasets' print(x, ...)
x |
an object used to select a method. |
... |
further arguments passed to or from other methods. |
Print datasets in the console
printDatasets( package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE )printDatasets( package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE )
package |
a character vector with the names of packages to search through, or NULL in which "all" packages (as defined by argument all) are searched. |
lib.loc |
a character vector of directory names of R libraries, or NULL. The default value of NULL corresponds to all libraries currently known. |
all |
logical; if TRUE search all available packages in the library trees specified by lib.loc, and if FALSE, search only attached packages. |
drop.defaults |
logical; if TRUE, do not include the datasets from the datasets package. |
Prompt for dataset in the console
promptDatasets( package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE )promptDatasets( package = NULL, lib.loc = NULL, all = TRUE, drop.defaults = FALSE )
package |
a character vector with the names of packages to search through, or NULL in which "all" packages (as defined by argument all) are searched. |
lib.loc |
a character vector of directory names of R libraries, or NULL. The default value of NULL corresponds to all libraries currently known. |
all |
logical; if TRUE search all available packages in the library trees specified by lib.loc, and if FALSE, search only attached packages. |
drop.defaults |
logical; if TRUE, do not include the datasets from the datasets package. |